@@ -3,7 +3,7 @@ package Narada;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv('1.3.15');
+our $VERSION = 'v1.4.0';
 
 1; # Magic true value required at end of module
 __END__
@@ -15,7 +15,7 @@ Narada - framework for ease development/deploy/support for medium/big projects
 
 =head1 VERSION
 
-This document describes Narada version 1.3.15
+This document describes Narada version v1.4.0
 
 
 =head1 SYNOPSIS
@@ -109,7 +109,7 @@ your website visitors won't even notice your daily backup!
 =back
 
 
-=head1 INTERFACE 
+=head1 INTERFACE
 
 Narada, as a framework, provide you with some interface (mostly it's just
 conventions about some files and directories), and you B<MUST> conform to
@@ -514,20 +514,21 @@ L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman@cpan.org> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
 =head1 CONTRIBUTORS
 
-Nick Levchenko C<< <project129@yandex.ru> >>
+Nick Levchenko E<lt>project129@yandex.ruE<gt>
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2008-2015 Alex Efros C<< <powerman@cpan.org> >>. All rights reserved.
+This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
 =head1 DISCLAIMER OF WARRANTY
@@ -551,4 +552,4 @@ THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+SUCH DAMAGES.
\ No newline at end of file
